@@ -43,6 +43,10 @@ inactivatemorph => "n",
 inactivatesim => "n",
 inactivateres => "n",
 incativateret => "n",
+direction => [ [ ">", ">", ">", ">", ">", ">", ">", ">" ] ], #These are the operator signs used to guide the direction of the search for each search block. There is a point to point correspondence with the variable "@sweeps". ">" means "up" and "<" means "down". This variable may be absente and it defaults to increasing order ">". #NEW
+precomputed => "/home/luca/f/precomputed.csv", #location of the precomputed results. THE PRESENCE OF THOSE INACTIVATES ALL THE SETTINGS FOR RETRIEVING AND REPORTING. #NEW
+takecolumns => [ 0, 16 ], #COMUMNS OF THE PRECOMPUTED RESULTS THAT HAS TO BE CONSIDERED AS INDICATOR. THIS OVERRIDES ALL THE SETTINGS FOR RETRIEVAL AND REPORTING. #NEW
+getresults = 
 actonexisting_models => { 1 => "y" },
 simtools => { 1 => "esp-r",
 #2 => "energyplus" 
